OC.L10N.register(
    "lib",
    {
    "Help" : "یارمەتی",
    "Users" : "به‌كارهێنه‌ر",
    "Admin" : "به‌ڕێوه‌به‌ری سه‌ره‌كی",
    "web services under your control" : "ڕاژه‌ی وێب له‌ژێر چاودێریت دایه",
    "Apps" : "به‌رنامه‌كان"
},
"nplurals=2; plural=(n != 1);");
